//===- testAA.cpp - Testing Loadable Alias Analysis -----------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file was developed by the LLVM research group and is distributed under
// the University of Illinois Open Source License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//
//
// empty AA impl to see if same LLVM failures occur
//
//===----------------------------------------------------------------------===//


#include "llvm/Constants.h"
#include "llvm/DerivedTypes.h"
#include "llvm/Module.h"
#include "llvm/Analysis/AliasAnalysis.h"
#include "llvm/Analysis/Passes.h"
#include "llvm/Pass.h"

using namespace llvm;

namespace {
  class TestAA : public ModulePass, public AliasAnalysis {
  public:
    static char ID;
    TestAA() : ModulePass((intptr_t)&ID) {}
    ~TestAA() {
    }

    //------------------------------------------------
    // Implement the Pass API
    //

    // run - Build up the result graph, representing the pointer graph for the
    // program.
    //
    bool runOnModule(Module &M) {
      InitializeAliasAnalysis(this);
      return false;
    }

    virtual void getAnalysisUsage(AnalysisUsage &AU) const {
      AliasAnalysis::getAnalysisUsage(AU);
      AU.setPreservesAll();                         // Does not transform code
    }

    //------------------------------------------------
    // Implement the AliasAnalysis API
    //

    AliasResult alias(const Value *V1, unsigned V1Size,
                      const Value *V2, unsigned V2Size) {
      return MayAlias;
    }

    ModRefResult getModRefInfo(CallSite CS, Value *P, unsigned Size) {
      return AliasAnalysis::getModRefInfo(CS,P,Size);
    }
    ModRefResult getModRefInfo(CallSite CS1, CallSite CS2) {
      return AliasAnalysis::getModRefInfo(CS1,CS2);
    }
  };

  // Register the pass...
  RegisterPass<TestAA> X("test-aa", "Testing (Dummy) AA");

  // Register as an implementation of AliasAnalysis
  RegisterAnalysisGroup<AliasAnalysis> Y(X);
}

char TestAA::ID;
